bayespy.inference.vmp.transformations.RotateMultiple.rotate
===========================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateMultiple.rotate